Documentation
¶
Overview ¶
Package internal implements various functionality (such as caching, emoji character mapping, and ID handling) relied upon by other packages in the Lightning suite.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Emoji = map[string]string{}/* 1833 elements not displayed */
Emoji is a mapping of Discord-style emoji shortcodes to their corresponding Unicode character representations.
Functions ¶
Types ¶
type Cache ¶
type Cache[K comparable, V any] struct { TTL time.Duration // contains filtered or unexported fields }
Cache represents an in-memory cache with a configurable TTL. If the TTL is set to -1, the cleanup routine will never be ran, and items will remain in memory until the process is killed. Concurrent access is safe across goroutines.
type ExtSpoiler ¶ added in v0.9.2
type ExtSpoiler struct{}
ExtSpoiler implements spoilers for goldmark.
func (*ExtSpoiler) Extend ¶ added in v0.9.2
func (*ExtSpoiler) Extend(m goldmark.Markdown)
Extend implements the spoiler parser.
type SpoilerNode ¶ added in v0.9.2
type SpoilerNode struct {
ast.BaseInline
}
SpoilerNode is an ast.Node for spoilers.
func (*SpoilerNode) Dump ¶ added in v0.9.2
func (n *SpoilerNode) Dump(src []byte, lvl int)
Dump returns information about the node.
func (*SpoilerNode) Kind ¶ added in v0.9.2
func (*SpoilerNode) Kind() ast.NodeKind
Kind returns the kind of node it is.