Documentation
¶
Overview ¶
Package api provides a lightning.Plugin implementation with a REST API which implements its own protocol in addition to support for Matterbridge. To use it with lightning, see New
bot := lightning.NewBot(...)
bot.AddPluginType("api", api.New)
bot.UsePluginType("api", "api", map[string]string{
// ...
})
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New creates a new lightning.Plugin with a REST API for Lightning
It only takes in a map with the following structure:
map[string]string{
"endpoint": "...", // optional, remote peer to stream events from if enabled
"type": "...", // optional, type of remote peer to stream from (matterbridge or lightning)
"token": "...", // optional, authentication token
}
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.