Documentation
¶
Overview ¶
Package matterbridge provides a lightning.Plugin implementation for the Matterbridge API. To use Matterbridge support with lightning, see New
bot := lightning.NewBot(...)
bot.AddPluginType("matterbridge", matterbridge.New)
bot.UsePluginType("matterbridge", "matterbridge", map[string]string{
// ...
})
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New creates a new lightning.Plugin that provides Matterbridge API support for Lightning
It only takes in a map with the following structure:
map[string]string{
"endpoint": "...", // optional, must be provided when in client mode and include a trailing /api
"mode": "...", // optional, must be either "client" or "server" (default)
"token": "..." // optional, authentication token
}
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.